# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class CurrencyTransaction(BaseModel):
    """
    货币交易记录实体，用于记录用户的货币交易详情。
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="货币交易记录的唯一标识符。")
    from_user_id: Optional[StrictInt] = Field(default=None, description="发起交易的发送方用户ID，若为转账交易时必填。", alias="fromUserID")
    user_id: Optional[StrictInt] = Field(default=None, description="进行货币交易的用户ID。", alias="userID")
    transaction_type: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="货币交易的类型，例如 '消费', '奖励', '兑换', '转账' 等。", alias="transactionType")
    currency_type: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="交易的货币类型，例如 'USD', 'CNY' 等。", alias="currencyType")
    currency_change: Optional[StrictInt] = Field(default=None, description="货币的变动数量，正数表示增加，负数表示减少。", alias="currencyChange")
    currency_balance: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="交易完成后的货币余额。", alias="currencyBalance")
    description: Optional[StrictStr] = Field(default=None, description="描述货币变动的具体原因或相关交易详情。")
    status: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="货币交易的当前状态，例如 '成功', '失败', '待审核' 等。")
    remark: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="交易的额外信息或管理员的备注。")
    tags: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用于分类或标记交易的标签。")
    create_date: Optional[datetime] = Field(default=None, description="货币交易发生的时间，默认为当前时间。", alias="createDate")
    __properties: ClassVar[List[str]] = ["id", "fromUserID", "userID", "transactionType", "currencyType", "currencyChange", "currencyBalance", "description", "status", "remark", "tags", "createDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CurrencyTransaction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if transaction_type (nullable) is None
        # and model_fields_set contains the field
        if self.transaction_type is None and "transaction_type" in self.model_fields_set:
            _dict['transactionType'] = None

        # set to None if currency_type (nullable) is None
        # and model_fields_set contains the field
        if self.currency_type is None and "currency_type" in self.model_fields_set:
            _dict['currencyType'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if remark (nullable) is None
        # and model_fields_set contains the field
        if self.remark is None and "remark" in self.model_fields_set:
            _dict['remark'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CurrencyTransaction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "fromUserID": obj.get("fromUserID"),
            "userID": obj.get("userID"),
            "transactionType": obj.get("transactionType"),
            "currencyType": obj.get("currencyType"),
            "currencyChange": obj.get("currencyChange"),
            "currencyBalance": obj.get("currencyBalance"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "remark": obj.get("remark"),
            "tags": obj.get("tags"),
            "createDate": obj.get("createDate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, List, Optional
from typing_extensions import Annotated
from ZSGF.Client.models.boolean_api_response import BooleanApiResponse
from ZSGF.Client.models.object_api_response import ObjectApiResponse
from ZSGF.Client.models.object_list_api_response import ObjectListApiResponse
from ZSGF.Client.models.storage_list_result_api_response import StorageListResultApiResponse
from ZSGF.Client.models.string_api_response import StringApiResponse

from ZSGF.Client.api_client import ApiClient, RequestSerialized
from ZSGF.Client.api_response import ApiResponse
from ZSGF.Client.rest import RESTResponseType


class StorageApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def storage_aggregate(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        app_key: StrictStr,
        pipeline: Annotated[Optional[StrictStr], Field(description="构建聚合查询")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ObjectListApiResponse:
        """聚合查询

        根据聚合管道查询指定表中的数据

        :param table: 表名称 (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param pipeline: 构建聚合查询
        :type pipeline: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_aggregate_serialize(
            table=table,
            app_key=app_key,
            pipeline=pipeline,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ObjectListApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def storage_aggregate_with_http_info(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        app_key: StrictStr,
        pipeline: Annotated[Optional[StrictStr], Field(description="构建聚合查询")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ObjectListApiResponse]:
        """聚合查询

        根据聚合管道查询指定表中的数据

        :param table: 表名称 (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param pipeline: 构建聚合查询
        :type pipeline: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_aggregate_serialize(
            table=table,
            app_key=app_key,
            pipeline=pipeline,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ObjectListApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def storage_aggregate_without_preload_content(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        app_key: StrictStr,
        pipeline: Annotated[Optional[StrictStr], Field(description="构建聚合查询")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """聚合查询

        根据聚合管道查询指定表中的数据

        :param table: 表名称 (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param pipeline: 构建聚合查询
        :type pipeline: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_aggregate_serialize(
            table=table,
            app_key=app_key,
            pipeline=pipeline,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ObjectListApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _storage_aggregate_serialize(
        self,
        table,
        app_key,
        pipeline,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if table is not None:
            _path_params['table'] = table
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if pipeline is not None:
            
            _query_params.append(('pipeline', pipeline))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Storage/{appKey}/{table}/Aggregate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def storage_delete(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BooleanApiResponse:
        """删除数据

        删除指定表中指定ID的数据

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_delete_serialize(
            table=table,
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def storage_delete_with_http_info(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BooleanApiResponse]:
        """删除数据

        删除指定表中指定ID的数据

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_delete_serialize(
            table=table,
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def storage_delete_without_preload_content(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """删除数据

        删除指定表中指定ID的数据

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_delete_serialize(
            table=table,
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _storage_delete_serialize(
        self,
        table,
        id,
        app_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if table is not None:
            _path_params['table'] = table
        if id is not None:
            _path_params['id'] = id
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/Storage/{appKey}/{table}/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def storage_detail(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        project: Annotated[Optional[StrictStr], Field(description="json格式")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ObjectApiResponse:
        """数据详情

        获取指定表中指定ID的数据详情

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param project: json格式
        :type project: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_detail_serialize(
            table=table,
            id=id,
            app_key=app_key,
            project=project,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ObjectApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def storage_detail_with_http_info(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        project: Annotated[Optional[StrictStr], Field(description="json格式")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ObjectApiResponse]:
        """数据详情

        获取指定表中指定ID的数据详情

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param project: json格式
        :type project: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_detail_serialize(
            table=table,
            id=id,
            app_key=app_key,
            project=project,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ObjectApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def storage_detail_without_preload_content(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        project: Annotated[Optional[StrictStr], Field(description="json格式")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """数据详情

        获取指定表中指定ID的数据详情

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param project: json格式
        :type project: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_detail_serialize(
            table=table,
            id=id,
            app_key=app_key,
            project=project,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ObjectApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _storage_detail_serialize(
        self,
        table,
        id,
        app_key,
        project,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if table is not None:
            _path_params['table'] = table
        if id is not None:
            _path_params['id'] = id
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if project is not None:
            
            _query_params.append(('project', project))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Storage/{appKey}/{table}/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def storage_list(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        app_key: StrictStr,
        filter: Annotated[Optional[StrictStr], Field(description="过滤，json格式")] = None,
        project: Annotated[Optional[StrictStr], Field(description="字段映射，json格式")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="排序，json格式")] = None,
        start_time: Annotated[Optional[datetime], Field(description="开始时间")] = None,
        end_time: Annotated[Optional[datetime], Field(description="结束时间")] = None,
        explain: Annotated[Optional[StrictBool], Field(description="查看执行计划")] = None,
        take: Annotated[Optional[StrictInt], Field(description="默认为10")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="默认为0")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StorageListResultApiResponse:
        """查询数据

        根据条件查询指定表中的数据

        :param table: 表名称 (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param filter: 过滤，json格式
        :type filter: str
        :param project: 字段映射，json格式
        :type project: str
        :param sort: 排序，json格式
        :type sort: str
        :param start_time: 开始时间
        :type start_time: datetime
        :param end_time: 结束时间
        :type end_time: datetime
        :param explain: 查看执行计划
        :type explain: bool
        :param take: 默认为10
        :type take: int
        :param skip: 默认为0
        :type skip: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_list_serialize(
            table=table,
            app_key=app_key,
            filter=filter,
            project=project,
            sort=sort,
            start_time=start_time,
            end_time=end_time,
            explain=explain,
            take=take,
            skip=skip,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StorageListResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def storage_list_with_http_info(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        app_key: StrictStr,
        filter: Annotated[Optional[StrictStr], Field(description="过滤，json格式")] = None,
        project: Annotated[Optional[StrictStr], Field(description="字段映射，json格式")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="排序，json格式")] = None,
        start_time: Annotated[Optional[datetime], Field(description="开始时间")] = None,
        end_time: Annotated[Optional[datetime], Field(description="结束时间")] = None,
        explain: Annotated[Optional[StrictBool], Field(description="查看执行计划")] = None,
        take: Annotated[Optional[StrictInt], Field(description="默认为10")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="默认为0")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StorageListResultApiResponse]:
        """查询数据

        根据条件查询指定表中的数据

        :param table: 表名称 (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param filter: 过滤，json格式
        :type filter: str
        :param project: 字段映射，json格式
        :type project: str
        :param sort: 排序，json格式
        :type sort: str
        :param start_time: 开始时间
        :type start_time: datetime
        :param end_time: 结束时间
        :type end_time: datetime
        :param explain: 查看执行计划
        :type explain: bool
        :param take: 默认为10
        :type take: int
        :param skip: 默认为0
        :type skip: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_list_serialize(
            table=table,
            app_key=app_key,
            filter=filter,
            project=project,
            sort=sort,
            start_time=start_time,
            end_time=end_time,
            explain=explain,
            take=take,
            skip=skip,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StorageListResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def storage_list_without_preload_content(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        app_key: StrictStr,
        filter: Annotated[Optional[StrictStr], Field(description="过滤，json格式")] = None,
        project: Annotated[Optional[StrictStr], Field(description="字段映射，json格式")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="排序，json格式")] = None,
        start_time: Annotated[Optional[datetime], Field(description="开始时间")] = None,
        end_time: Annotated[Optional[datetime], Field(description="结束时间")] = None,
        explain: Annotated[Optional[StrictBool], Field(description="查看执行计划")] = None,
        take: Annotated[Optional[StrictInt], Field(description="默认为10")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="默认为0")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """查询数据

        根据条件查询指定表中的数据

        :param table: 表名称 (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param filter: 过滤，json格式
        :type filter: str
        :param project: 字段映射，json格式
        :type project: str
        :param sort: 排序，json格式
        :type sort: str
        :param start_time: 开始时间
        :type start_time: datetime
        :param end_time: 结束时间
        :type end_time: datetime
        :param explain: 查看执行计划
        :type explain: bool
        :param take: 默认为10
        :type take: int
        :param skip: 默认为0
        :type skip: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_list_serialize(
            table=table,
            app_key=app_key,
            filter=filter,
            project=project,
            sort=sort,
            start_time=start_time,
            end_time=end_time,
            explain=explain,
            take=take,
            skip=skip,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StorageListResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _storage_list_serialize(
        self,
        table,
        app_key,
        filter,
        project,
        sort,
        start_time,
        end_time,
        explain,
        take,
        skip,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if table is not None:
            _path_params['table'] = table
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if filter is not None:
            
            _query_params.append(('filter', filter))
            
        if project is not None:
            
            _query_params.append(('project', project))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if start_time is not None:
            if isinstance(start_time, datetime):
                _query_params.append(
                    (
                        'startTime',
                        start_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('startTime', start_time))
            
        if end_time is not None:
            if isinstance(end_time, datetime):
                _query_params.append(
                    (
                        'endTime',
                        end_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('endTime', end_time))
            
        if explain is not None:
            
            _query_params.append(('explain', explain))
            
        if take is not None:
            
            _query_params.append(('take', take))
            
        if skip is not None:
            
            _query_params.append(('skip', skip))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Storage/{appKey}/{table}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def storage_post(
        self,
        table: Annotated[str, Field(strict=True, description="表名称（小写字母加数字,1-50位）")],
        app_key: StrictStr,
        request_body: Annotated[List[Any], Field(description="json对象 / json数组")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> StringApiResponse:
        """添加数据

        向指定表中添加数据，可以是单个json对象或json数组

        :param table: 表名称（小写字母加数字,1-50位） (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param request_body: json对象 / json数组 (required)
        :type request_body: List[object]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_post_serialize(
            table=table,
            app_key=app_key,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StringApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def storage_post_with_http_info(
        self,
        table: Annotated[str, Field(strict=True, description="表名称（小写字母加数字,1-50位）")],
        app_key: StrictStr,
        request_body: Annotated[List[Any], Field(description="json对象 / json数组")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[StringApiResponse]:
        """添加数据

        向指定表中添加数据，可以是单个json对象或json数组

        :param table: 表名称（小写字母加数字,1-50位） (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param request_body: json对象 / json数组 (required)
        :type request_body: List[object]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_post_serialize(
            table=table,
            app_key=app_key,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StringApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def storage_post_without_preload_content(
        self,
        table: Annotated[str, Field(strict=True, description="表名称（小写字母加数字,1-50位）")],
        app_key: StrictStr,
        request_body: Annotated[List[Any], Field(description="json对象 / json数组")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """添加数据

        向指定表中添加数据，可以是单个json对象或json数组

        :param table: 表名称（小写字母加数字,1-50位） (required)
        :type table: str
        :param app_key: (required)
        :type app_key: str
        :param request_body: json对象 / json数组 (required)
        :type request_body: List[object]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_post_serialize(
            table=table,
            app_key=app_key,
            request_body=request_body,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "StringApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _storage_post_serialize(
        self,
        table,
        app_key,
        request_body,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'request_body': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if table is not None:
            _path_params['table'] = table
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request_body is not None:
            _body_params = request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json-patch+json', 
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/Storage/{appKey}/{table}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def storage_put(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        request_body: Annotated[List[Any], Field(description="json格式")],
        replace: Annotated[Optional[StrictBool], Field(description="是否为全量更新，默认为false")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BooleanApiResponse:
        """更新数据

        更新指定表中指定ID的数据，可以选择全量更新或部分更新

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param request_body: json格式 (required)
        :type request_body: List[object]
        :param replace: 是否为全量更新，默认为false
        :type replace: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_put_serialize(
            table=table,
            id=id,
            app_key=app_key,
            request_body=request_body,
            replace=replace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def storage_put_with_http_info(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        request_body: Annotated[List[Any], Field(description="json格式")],
        replace: Annotated[Optional[StrictBool], Field(description="是否为全量更新，默认为false")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BooleanApiResponse]:
        """更新数据

        更新指定表中指定ID的数据，可以选择全量更新或部分更新

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param request_body: json格式 (required)
        :type request_body: List[object]
        :param replace: 是否为全量更新，默认为false
        :type replace: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_put_serialize(
            table=table,
            id=id,
            app_key=app_key,
            request_body=request_body,
            replace=replace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def storage_put_without_preload_content(
        self,
        table: Annotated[str, Field(strict=True, description="表名称")],
        id: Annotated[StrictStr, Field(description="数据ID")],
        app_key: StrictStr,
        request_body: Annotated[List[Any], Field(description="json格式")],
        replace: Annotated[Optional[StrictBool], Field(description="是否为全量更新，默认为false")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """更新数据

        更新指定表中指定ID的数据，可以选择全量更新或部分更新

        :param table: 表名称 (required)
        :type table: str
        :param id: 数据ID (required)
        :type id: str
        :param app_key: (required)
        :type app_key: str
        :param request_body: json格式 (required)
        :type request_body: List[object]
        :param replace: 是否为全量更新，默认为false
        :type replace: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._storage_put_serialize(
            table=table,
            id=id,
            app_key=app_key,
            request_body=request_body,
            replace=replace,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BooleanApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _storage_put_serialize(
        self,
        table,
        id,
        app_key,
        request_body,
        replace,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'request_body': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if table is not None:
            _path_params['table'] = table
        if id is not None:
            _path_params['id'] = id
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if replace is not None:
            
            _query_params.append(('replace', replace))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request_body is not None:
            _body_params = request_body


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json-patch+json', 
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/Storage/{appKey}/{table}/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class GrantRequest(BaseModel):
    """
    GrantRequest
    """ # noqa: E501
    redirect_uri: Optional[StrictStr] = Field(default=None, description="返回地址。默认无限制，也可在【安全-开放认证网址白名单】配置")
    grant_type: Annotated[str, Field(min_length=1, strict=True)] = Field(description="授权类型。可选：email、phone、unionid、account")
    scopes: Annotated[str, Field(min_length=1, strict=True)] = Field(description="自定义授权范围，用英文空格分隔")
    user_name: Optional[StrictStr] = Field(default=None, description="用户名。授权类型为：email/phone/account必填", alias="userName")
    password: Optional[StrictStr] = Field(default=None, description="登录密码。授权类型为：email/phone/account必填")
    union_id: Optional[StrictStr] = Field(default=None, description="unionId。授权类型为：unionid必填", alias="unionId")
    platform: Optional[StrictStr] = Field(default=None, description="平台。授权类型为：unionid必填")
    expire_in_days: Optional[Annotated[int, Field(le=99, strict=True, ge=1)]] = Field(default=None, description="授权有效期。1~99天", alias="expireInDays")
    __properties: ClassVar[List[str]] = ["redirect_uri", "grant_type", "scopes", "userName", "password", "unionId", "platform", "expireInDays"]

    @field_validator('grant_type')
    def grant_type_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^(email|phone|unionid|account)$", value):
            raise ValueError(r"must validate the regular expression /^(email|phone|unionid|account)$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GrantRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if redirect_uri (nullable) is None
        # and model_fields_set contains the field
        if self.redirect_uri is None and "redirect_uri" in self.model_fields_set:
            _dict['redirect_uri'] = None

        # set to None if user_name (nullable) is None
        # and model_fields_set contains the field
        if self.user_name is None and "user_name" in self.model_fields_set:
            _dict['userName'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if union_id (nullable) is None
        # and model_fields_set contains the field
        if self.union_id is None and "union_id" in self.model_fields_set:
            _dict['unionId'] = None

        # set to None if platform (nullable) is None
        # and model_fields_set contains the field
        if self.platform is None and "platform" in self.model_fields_set:
            _dict['platform'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GrantRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "redirect_uri": obj.get("redirect_uri"),
            "grant_type": obj.get("grant_type"),
            "scopes": obj.get("scopes"),
            "userName": obj.get("userName"),
            "password": obj.get("password"),
            "unionId": obj.get("unionId"),
            "platform": obj.get("platform"),
            "expireInDays": obj.get("expireInDays")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class Order(BaseModel):
    """
    订单实体，用于记录用户的订单信息。
    """ # noqa: E501
    id: Optional[StrictInt] = Field(default=None, description="订单的唯一标识符。")
    user_id: Optional[StrictInt] = Field(default=None, description="创建订单的用户ID。", alias="userID")
    pay_type: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="订单的支付类型，例如 '信用卡', '支付宝', '微信支付' 等。", alias="payType")
    amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="订单的总金额。")
    order_no: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="订单的唯一编号，通常由系统生成。", alias="orderNo")
    trade_no: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="与订单关联的交易编号，通常由支付平台提供。", alias="tradeNo")
    status: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="订单的当前状态，例如 '待支付', '已完成', '已取消' 等。")
    product_type: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="订单中商品的类型分类。", alias="productType")
    product_id: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="订单中商品的唯一标识符。", alias="productID")
    product_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="订单中商品的名称。", alias="productName")
    allow_refund: Optional[StrictBool] = Field(default=None, description="指示订单是否允许进行退款操作。", alias="allowRefund")
    allow_refund_until: Optional[datetime] = Field(default=None, description="订单允许进行退款操作的截止时间。", alias="allowRefundUntil")
    tags: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用于分类或标记订单的标签。")
    remark: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="订单的额外备注信息。")
    description: Optional[StrictStr] = Field(default=None, description="订单的详细描述信息。")
    order_pay_time: Optional[datetime] = Field(default=None, description="订单完成支付的时间。", alias="orderPayTime")
    expire_time: Optional[datetime] = Field(default=None, description="订单的过期时间，超过该时间订单将自动取消。", alias="expireTime")
    create_date: Optional[datetime] = Field(default=None, description="订单的创建时间，默认为当前时间。", alias="createDate")
    last_update: Optional[datetime] = Field(default=None, description="订单的最后更新时间，默认为当前时间。", alias="lastUpdate")
    __properties: ClassVar[List[str]] = ["id", "userID", "payType", "amount", "orderNo", "tradeNo", "status", "productType", "productID", "productName", "allowRefund", "allowRefundUntil", "tags", "remark", "description", "orderPayTime", "expireTime", "createDate", "lastUpdate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Order from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if pay_type (nullable) is None
        # and model_fields_set contains the field
        if self.pay_type is None and "pay_type" in self.model_fields_set:
            _dict['payType'] = None

        # set to None if order_no (nullable) is None
        # and model_fields_set contains the field
        if self.order_no is None and "order_no" in self.model_fields_set:
            _dict['orderNo'] = None

        # set to None if trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.trade_no is None and "trade_no" in self.model_fields_set:
            _dict['tradeNo'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if product_type (nullable) is None
        # and model_fields_set contains the field
        if self.product_type is None and "product_type" in self.model_fields_set:
            _dict['productType'] = None

        # set to None if product_id (nullable) is None
        # and model_fields_set contains the field
        if self.product_id is None and "product_id" in self.model_fields_set:
            _dict['productID'] = None

        # set to None if product_name (nullable) is None
        # and model_fields_set contains the field
        if self.product_name is None and "product_name" in self.model_fields_set:
            _dict['productName'] = None

        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        # set to None if remark (nullable) is None
        # and model_fields_set contains the field
        if self.remark is None and "remark" in self.model_fields_set:
            _dict['remark'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Order from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "userID": obj.get("userID"),
            "payType": obj.get("payType"),
            "amount": obj.get("amount"),
            "orderNo": obj.get("orderNo"),
            "tradeNo": obj.get("tradeNo"),
            "status": obj.get("status"),
            "productType": obj.get("productType"),
            "productID": obj.get("productID"),
            "productName": obj.get("productName"),
            "allowRefund": obj.get("allowRefund"),
            "allowRefundUntil": obj.get("allowRefundUntil"),
            "tags": obj.get("tags"),
            "remark": obj.get("remark"),
            "description": obj.get("description"),
            "orderPayTime": obj.get("orderPayTime"),
            "expireTime": obj.get("expireTime"),
            "createDate": obj.get("createDate"),
            "lastUpdate": obj.get("lastUpdate")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ProfileResult(BaseModel):
    """
    ProfileResult
    """ # noqa: E501
    id: Optional[StrictInt] = None
    union_id: Optional[StrictStr] = Field(default=None, alias="unionID")
    phone: Optional[StrictStr] = None
    create_date: Optional[datetime] = Field(default=None, alias="createDate")
    user_name: Optional[StrictStr] = Field(default=None, alias="userName")
    phone_is_valid: Optional[StrictBool] = Field(default=None, alias="phoneIsValid")
    data: Optional[StrictStr] = None
    email: Optional[StrictStr] = None
    email_is_valid: Optional[StrictBool] = Field(default=None, alias="emailIsValid")
    last_update: Optional[datetime] = Field(default=None, alias="lastUpdate")
    nick_name: Optional[StrictStr] = Field(default=None, alias="nickName")
    avatar: Optional[StrictStr] = None
    role: Optional[StrictStr] = None
    permission: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "unionID", "phone", "createDate", "userName", "phoneIsValid", "data", "email", "emailIsValid", "lastUpdate", "nickName", "avatar", "role", "permission"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProfileResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if union_id (nullable) is None
        # and model_fields_set contains the field
        if self.union_id is None and "union_id" in self.model_fields_set:
            _dict['unionID'] = None

        # set to None if phone (nullable) is None
        # and model_fields_set contains the field
        if self.phone is None and "phone" in self.model_fields_set:
            _dict['phone'] = None

        # set to None if user_name (nullable) is None
        # and model_fields_set contains the field
        if self.user_name is None and "user_name" in self.model_fields_set:
            _dict['userName'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if email (nullable) is None
        # and model_fields_set contains the field
        if self.email is None and "email" in self.model_fields_set:
            _dict['email'] = None

        # set to None if nick_name (nullable) is None
        # and model_fields_set contains the field
        if self.nick_name is None and "nick_name" in self.model_fields_set:
            _dict['nickName'] = None

        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if role (nullable) is None
        # and model_fields_set contains the field
        if self.role is None and "role" in self.model_fields_set:
            _dict['role'] = None

        # set to None if permission (nullable) is None
        # and model_fields_set contains the field
        if self.permission is None and "permission" in self.model_fields_set:
            _dict['permission'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProfileResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "unionID": obj.get("unionID"),
            "phone": obj.get("phone"),
            "createDate": obj.get("createDate"),
            "userName": obj.get("userName"),
            "phoneIsValid": obj.get("phoneIsValid"),
            "data": obj.get("data"),
            "email": obj.get("email"),
            "emailIsValid": obj.get("emailIsValid"),
            "lastUpdate": obj.get("lastUpdate"),
            "nickName": obj.get("nickName"),
            "avatar": obj.get("avatar"),
            "role": obj.get("role"),
            "permission": obj.get("permission")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class UpdateProfileRequest(BaseModel):
    """
    UpdateProfileRequest
    """ # noqa: E501
    avatar: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="用户头像的链接或路径，长度不能超过255个字符")
    data: Optional[StrictStr] = Field(default=None, description="用户的其他数据，可以是序列化后的对象或JSON字符串")
    nick_name: Optional[Annotated[str, Field(min_length=4, strict=True, max_length=32)]] = Field(default=None, description="用户的昵称，长度不能超过50个字符", alias="nickName")
    interest_tags: Optional[StrictStr] = Field(default=None, description="兴趣标签", alias="interestTags")
    biography: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="个人简介，长度不能超过500个字符")
    gender: Optional[Annotated[str, Field(strict=True, max_length=15)]] = Field(default=None, description="性别，长度不能超过15个字符")
    birthday: Optional[datetime] = Field(default=None, description="生日")
    occupation: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="职业，长度不能超过50个字符")
    education: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="学历，长度不能超过50个字符")
    contact: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="联系方式，长度不能超过255个字符")
    languages: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="语言，长度不能超过50个字符")
    social_links: Optional[Annotated[str, Field(strict=True, max_length=255)]] = Field(default=None, description="社交网络链接，长度不能超过255个字符", alias="socialLinks")
    relationship_status: Optional[Annotated[str, Field(strict=True, max_length=20)]] = Field(default=None, description="婚姻状态，长度不能超过20个字符", alias="relationshipStatus")
    company: Optional[Annotated[str, Field(strict=True, max_length=100)]] = Field(default=None, description="公司，长度不能超过100个字符")
    industry: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="行业，长度不能超过50个字符")
    company_position: Optional[Annotated[str, Field(strict=True, max_length=50)]] = Field(default=None, description="行业职位，长度不能超过50个字符", alias="companyPosition")
    private_settings: Optional[Annotated[str, Field(strict=True, max_length=500)]] = Field(default=None, description="私密设置，长度不能超过500个字符", alias="privateSettings")
    enable2_fa_auth: Optional[StrictBool] = Field(default=None, description="是否启用二步验证", alias="enable2FAAuth")
    enable_user_name_sign_in: Optional[StrictBool] = Field(default=None, description="是否启用账号登录", alias="enableUserNameSignIn")
    enable_email_sign_in: Optional[StrictBool] = Field(default=None, description="是否启用邮箱登录", alias="enableEmailSignIn")
    enable_phone_sign_in: Optional[StrictBool] = Field(default=None, description="是否启用手机登录", alias="enablePhoneSignIn")
    enable_union_id_sign_in: Optional[StrictBool] = Field(default=None, description="是否启用UnionID登录", alias="enableUnionIDSignIn")
    enable_o_auth: Optional[StrictBool] = Field(default=None, description="是否启用OAuth2登录", alias="enableOAuth")
    __properties: ClassVar[List[str]] = ["avatar", "data", "nickName", "interestTags", "biography", "gender", "birthday", "occupation", "education", "contact", "languages", "socialLinks", "relationshipStatus", "company", "industry", "companyPosition", "privateSettings", "enable2FAAuth", "enableUserNameSignIn", "enableEmailSignIn", "enablePhoneSignIn", "enableUnionIDSignIn", "enableOAuth"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpdateProfileRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if data (nullable) is None
        # and model_fields_set contains the field
        if self.data is None and "data" in self.model_fields_set:
            _dict['data'] = None

        # set to None if nick_name (nullable) is None
        # and model_fields_set contains the field
        if self.nick_name is None and "nick_name" in self.model_fields_set:
            _dict['nickName'] = None

        # set to None if interest_tags (nullable) is None
        # and model_fields_set contains the field
        if self.interest_tags is None and "interest_tags" in self.model_fields_set:
            _dict['interestTags'] = None

        # set to None if biography (nullable) is None
        # and model_fields_set contains the field
        if self.biography is None and "biography" in self.model_fields_set:
            _dict['biography'] = None

        # set to None if gender (nullable) is None
        # and model_fields_set contains the field
        if self.gender is None and "gender" in self.model_fields_set:
            _dict['gender'] = None

        # set to None if birthday (nullable) is None
        # and model_fields_set contains the field
        if self.birthday is None and "birthday" in self.model_fields_set:
            _dict['birthday'] = None

        # set to None if occupation (nullable) is None
        # and model_fields_set contains the field
        if self.occupation is None and "occupation" in self.model_fields_set:
            _dict['occupation'] = None

        # set to None if education (nullable) is None
        # and model_fields_set contains the field
        if self.education is None and "education" in self.model_fields_set:
            _dict['education'] = None

        # set to None if contact (nullable) is None
        # and model_fields_set contains the field
        if self.contact is None and "contact" in self.model_fields_set:
            _dict['contact'] = None

        # set to None if languages (nullable) is None
        # and model_fields_set contains the field
        if self.languages is None and "languages" in self.model_fields_set:
            _dict['languages'] = None

        # set to None if social_links (nullable) is None
        # and model_fields_set contains the field
        if self.social_links is None and "social_links" in self.model_fields_set:
            _dict['socialLinks'] = None

        # set to None if relationship_status (nullable) is None
        # and model_fields_set contains the field
        if self.relationship_status is None and "relationship_status" in self.model_fields_set:
            _dict['relationshipStatus'] = None

        # set to None if company (nullable) is None
        # and model_fields_set contains the field
        if self.company is None and "company" in self.model_fields_set:
            _dict['company'] = None

        # set to None if industry (nullable) is None
        # and model_fields_set contains the field
        if self.industry is None and "industry" in self.model_fields_set:
            _dict['industry'] = None

        # set to None if company_position (nullable) is None
        # and model_fields_set contains the field
        if self.company_position is None and "company_position" in self.model_fields_set:
            _dict['companyPosition'] = None

        # set to None if private_settings (nullable) is None
        # and model_fields_set contains the field
        if self.private_settings is None and "private_settings" in self.model_fields_set:
            _dict['privateSettings'] = None

        # set to None if enable2_fa_auth (nullable) is None
        # and model_fields_set contains the field
        if self.enable2_fa_auth is None and "enable2_fa_auth" in self.model_fields_set:
            _dict['enable2FAAuth'] = None

        # set to None if enable_user_name_sign_in (nullable) is None
        # and model_fields_set contains the field
        if self.enable_user_name_sign_in is None and "enable_user_name_sign_in" in self.model_fields_set:
            _dict['enableUserNameSignIn'] = None

        # set to None if enable_email_sign_in (nullable) is None
        # and model_fields_set contains the field
        if self.enable_email_sign_in is None and "enable_email_sign_in" in self.model_fields_set:
            _dict['enableEmailSignIn'] = None

        # set to None if enable_phone_sign_in (nullable) is None
        # and model_fields_set contains the field
        if self.enable_phone_sign_in is None and "enable_phone_sign_in" in self.model_fields_set:
            _dict['enablePhoneSignIn'] = None

        # set to None if enable_union_id_sign_in (nullable) is None
        # and model_fields_set contains the field
        if self.enable_union_id_sign_in is None and "enable_union_id_sign_in" in self.model_fields_set:
            _dict['enableUnionIDSignIn'] = None

        # set to None if enable_o_auth (nullable) is None
        # and model_fields_set contains the field
        if self.enable_o_auth is None and "enable_o_auth" in self.model_fields_set:
            _dict['enableOAuth'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpdateProfileRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "avatar": obj.get("avatar"),
            "data": obj.get("data"),
            "nickName": obj.get("nickName"),
            "interestTags": obj.get("interestTags"),
            "biography": obj.get("biography"),
            "gender": obj.get("gender"),
            "birthday": obj.get("birthday"),
            "occupation": obj.get("occupation"),
            "education": obj.get("education"),
            "contact": obj.get("contact"),
            "languages": obj.get("languages"),
            "socialLinks": obj.get("socialLinks"),
            "relationshipStatus": obj.get("relationshipStatus"),
            "company": obj.get("company"),
            "industry": obj.get("industry"),
            "companyPosition": obj.get("companyPosition"),
            "privateSettings": obj.get("privateSettings"),
            "enable2FAAuth": obj.get("enable2FAAuth"),
            "enableUserNameSignIn": obj.get("enableUserNameSignIn"),
            "enableEmailSignIn": obj.get("enableEmailSignIn"),
            "enablePhoneSignIn": obj.get("enablePhoneSignIn"),
            "enableUnionIDSignIn": obj.get("enableUnionIDSignIn"),
            "enableOAuth": obj.get("enableOAuth")
        })
        return _obj


